==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/pl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nieznany adres",
    "No result." : "Brak wyników.",
    "Malformed JSON data." : "Nieprawidłowe dane JSON.",
    "Error" : "Błąd",
    "Weather status" : "Stan pogody",
    "Weather status in your dashboard" : "Stan pogody na pulpicie",
    "Detect location" : "Wykryj lokalizację",
    "Set custom address" : "Ustaw adres własny",
    "Favorites" : "Ulubione",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} bezchmurne niebo później dzisiaj",
    "{temperature} {unit} clear sky" : "{temperature} {unit} czyste niebo",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} pochmurno później dzisiaj",
    "{temperature} {unit} cloudy" : "{temperature} {unit} pochmurno",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} ładna pogoda później dzisiaj",
    "{temperature} {unit} fair weather" : "{temperature} {unit} ładna pogoda",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} częściowe zachmurzenie później dzisiaj",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} częściowe zachmurzenie",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} mgła później dzisiaj",
    "{temperature} {unit} foggy" : "{temperature} {unit} mgła",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lekkie opady deszczu później dzisiaj",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lekkie opady deszczu",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} opady deszczu później dzisiaj",
    "{temperature} {unit} rainfall" : "{temperature} {unit} opady deszczu",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} ulewne opady deszczu później dzisiaj",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} ulewne opady deszczu",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} przelotne opady deszczu później dzisiaj",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} przelotne opady deszczu",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lekkie przelotne opady deszczu później dzisiaj",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lekkie przelotne opady deszczu",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} obfite opady deszczu później dzisiaj",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} ulewne opady deszczu",
    "More weather for {adr}" : "Więcej pogody dla {adr}",
    "Loading weather" : "Wczytywanie pogody",
    "Set location for weather" : "Ustaw lokalizację dla pogody",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add as favorite" : "Dodaj jako ulubione",
    "You are not logged in." : "Nie jesteś zalogowany.",
    "There was an error getting the weather status information." : "Wystąpił błąd podczas pobierania informacji o stanie pogody.",
    "No weather information found" : "Nie znaleziono informacji o pogodzie",
    "Location not found" : "Nie znaleziono lokalizacji",
    "There was an error setting the location address." : "Wystąpił błąd podczas ustawiania adresu lokalizacji.",
    "There was an error setting the location." : "Wystąpił błąd podczas ustawiania lokalizacji.",
    "There was an error saving the mode." : "Wystąpił błąd podczas zapisywania trybu.",
    "There was an error using personal address." : "Wystąpił błąd podczas korzystania z własnego adresu."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/weather_status/l10n/pl.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Nieznany adres",
    "No result." : "Brak wyników.",
    "Malformed JSON data." : "Nieprawidłowe dane JSON.",
    "Error" : "Błąd",
    "Weather status" : "Stan pogody",
    "Weather status in your dashboard" : "Stan pogody na pulpicie",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status pogody zintegrowany z aplikacją Panelu.\nPołożenie geograficzne może być automatycznie ustalane lub ręcznie definiowane. Wyświetlana jest prognoza na 6 godzin.\nStatus może być również integrowany z innymi aplikacjami, takimi jak Kalendarz.",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} bezchmurne niebo później dzisiaj",
    "{temperature} {unit} clear sky" : "{temperature} {unit} czyste niebo",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} pochmurno później dzisiaj",
    "{temperature} {unit} cloudy" : "{temperature} {unit} pochmurno",
    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit} śnieg i burza później dziś",
    "{temperature} {unit} snow and thunder" : "{temperature} {unit} śnieg i burza",
    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit} przelotne opady śniegu i burza później dziś",
    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} przelotne opady śniegu i burza",
    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit} przelotne opady śniegu, burza i zmierzch polarny później dziś",
    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} przelotne opady śniegu, burza i zmierzch polarny",
    "{temperature} {unit} snow showers later today" : "{temperature} {unit} przelotne opady śniegu później dziś",
    "{temperature} {unit} snow showers" : "{temperature} {unit} przelotne opady śniegu",
    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} przelotne opady śniegu i zmierzch polarny później dziś",
    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} przelotne opady śniegu i zmierzch polarny",
    "{temperature} {unit} snow later today" : "{temperature} {unit} śnieg później dziś",
    "{temperature} {unit} snow" : "{temperature} {unit} śnieg",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} ładna pogoda później dzisiaj",
    "{temperature} {unit} fair weather" : "{temperature} {unit} ładna pogoda",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} częściowe zachmurzenie później dzisiaj",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} częściowe zachmurzenie",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} mgła później dzisiaj",
    "{temperature} {unit} foggy" : "{temperature} {unit} mgła",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} lekkie opady deszczu później dzisiaj",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} lekkie opady deszczu",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} opady deszczu później dzisiaj",
    "{temperature} {unit} rainfall" : "{temperature} {unit} opady deszczu",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} ulewne opady deszczu później dzisiaj",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} ulewne opady deszczu",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} przelotne opady deszczu później dzisiaj",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} przelotne opady deszczu",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} lekkie przelotne opady deszczu później dzisiaj",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} lekkie przelotne opady deszczu",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} obfite opady deszczu później dzisiaj",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} ulewne opady deszczu",
    "More weather for {adr}" : "Więcej pogody dla {adr}",
    "Loading weather" : "Wczytywanie pogody",
    "Set location for weather" : "Ustaw lokalizację dla pogody",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add as favorite" : "Dodaj jako ulubione",
    "You are not logged in." : "Nie jesteś zalogowany.",
    "There was an error getting the weather status information." : "Wystąpił błąd podczas pobierania informacji o stanie pogody.",
    "No weather information found" : "Nie znaleziono informacji o pogodzie",
    "Location not found" : "Nie znaleziono lokalizacji",
    "There was an error setting the location address." : "Wystąpił błąd podczas ustawiania adresu lokalizacji.",
    "There was an error setting the location." : "Wystąpił błąd podczas ustawiania lokalizacji.",
    "There was an error saving the mode." : "Wystąpił błąd podczas zapisywania trybu.",
    "There was an error using personal address." : "Wystąpił błąd podczas korzystania z własnego adresu.",
    "Unknown weather code" : "Nieznany kod pogodowy",
    "Detect location" : "Wykryj lokalizację",
    "Set custom address" : "Ustaw adres własny",
    "Favorites" : "Ulubione"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
